;-------------------------------------------------------------
;+
; NAME:
;       JD2YMD
; PURPOSE:
;       Find year, month, day from julian day number.
; CATEGORY:
; CALLING SEQUENCE:
;       jd2ymd, jd, y, m, d
; INPUTS:
;       jd = Julian day number (like 2447000).     in
; KEYWORD PARAMETERS:
; OUTPUTS:
;       y = year (like 1987).                      out
;       m = month number (like 7).                 out
;       d = day of month (like 23).                out
; COMMON BLOCKS:
; NOTES:
;       Uses the algorithm by Meeus in Astronomical algorithms
; RESTRICTIONS:
;       o jd should be double or long type.
;       o Will not work for negative JD.
; MODIFICATION HISTORY:
;       T. Metcalf January 1994
;-
;-------------------------------------------------------------
 
	PRO JD2YMD, JD, Year, Month, Day, help=hlp
 
	IF (N_PARAMS(0) LT 4) or keyword_set(hlp) THEN BEGIN
	  PRINT,' Find year, month, day from julian day number.'
	  PRINT,' jd2ymd, jd, y, m, d'
	  PRINT,'   jd = Julian day number (like 2447000).     in'
	  PRINT,'   y = year (like 1987).                      out'
	  PRINT,'   m = month number (like 7).                 out'
	  PRINT,'   d = day of month (like 23).                out'
	  RETURN
	ENDIF
 
        jdnew = jd + 0.5d0
        z = double(long(jdnew))
        f = jdnew - z

        if z LT 2299161L then a = z $
        else begin
           alpha = double(long((z-1867216.25d0)/36524.25d0))
           a = z + 1.0d0 + alpha - double(long(alpha/4.0d0))
        endelse

        b = a + 1524.0d0
        c = long((b-122.1d0)/365.25d0)
        d = long(365.25d0*double(c))
        e = long(double(b-d)/30.6001d0)

        day = b-d-double(long(30.6001d0*e))+f
        if e LT 14L then month = e-1L else month = e-13L

        if month GT 2L then year = c-4716L else year = c-4715L
 
	RETURN
	END
