;-------------------------------------------------------------
;+
; NAME:
;       YMD2JD
; PURPOSE:
;       From Year, Month, and Day compute Julian Day number.
; CATEGORY:
; CALLING SEQUENCE:
;       jd = ymd2jd(y,m,d)
; INPUTS:
;       y = Year (like 1987).                    in
;       m = month (like 7 for July).             in
;       d = month day (like 23).                 in
; KEYWORD PARAMETERS:
;       /julian = Calculate the date in the Julian rather than the Gregorian 
;                 calendar
; OUTPUTS:
;       jd = Julian Day number (like 2447000).   out
; COMMON BLOCKS:
; NOTES:
;       Uses the algorithm of Meeus, Astronomical Algorithms
; MODIFICATION HISTORY:
;       T. Metcalf January 1994
;-
;-------------------------------------------------------------
 
	FUNCTION YMD2JD, IY, IM, ID, help=hlp, julian=julian
 
	IF (N_PARAMS(0) LT 3) or keyword_set(hlp) THEN BEGIN
	  PRINT,' From Year, Month, and Day compute Julian Day number.'
	  PRINT,' jd = ymd2jd(y,m,d)'
	  PRINT,'   y = Year (like 1987).                    in'
	  PRINT,'   m = month (like 7 for July).             in'
	  PRINT,'   d = month day (like 23).                 in'
	  PRINT,'   jd = Julian Day number (like 2447000).   out'
	  RETURN, -1
	ENDIF
 
	M = long(IM)
        if M GT 2L then Y = long(IY) $
        else begin
           Y = long(IY) - 1L
           M = M + 12L
        endelse
        D = double(ID)

        if keyword_set(julian) then B=0.0d0 $
        else begin
           A = long(Y/100L)
           B = 2.0d0 - A + long(A/4L)
        endelse
        

	JD = double(long(365.25d0*(Y+4716.0d0))) + $
             double(long(30.6001d0*(M+1L))) + $
             D + B - 1524.5d0
 
	RETURN, JD
 
	END
